cmomy.CentralMoments
====================

.. currentmodule:: cmomy

.. autoclass:: CentralMoments
   :show-inheritance:

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: 
   
      ~CentralMoments.__init__
      ~CentralMoments.block
      ~CentralMoments.cmom
      ~CentralMoments.copy
      ~CentralMoments.fill
      ~CentralMoments.from_data
      ~CentralMoments.from_datas
      ~CentralMoments.from_raw
      ~CentralMoments.from_raws
      ~CentralMoments.from_resample_vals
      ~CentralMoments.from_stat
      ~CentralMoments.from_stats
      ~CentralMoments.from_vals
      ~CentralMoments.mean
      ~CentralMoments.moveaxis
      ~CentralMoments.new_like
      ~CentralMoments.push_data
      ~CentralMoments.push_datas
      ~CentralMoments.push_stat
      ~CentralMoments.push_stats
      ~CentralMoments.push_val
      ~CentralMoments.push_vals
      ~CentralMoments.reduce
      ~CentralMoments.resample
      ~CentralMoments.resample_and_reduce
      ~CentralMoments.reshape
      ~CentralMoments.rmom
      ~CentralMoments.std
      ~CentralMoments.to_raw
      ~CentralMoments.var
      ~CentralMoments.weight
      ~CentralMoments.zero
      ~CentralMoments.zeros
      ~CentralMoments.zeros_like
   
   

   
   
   .. rubric:: Attributes
   
   .. autosummary::
      :toctree: 
   
      ~CentralMoments.data
      ~CentralMoments.dtype
      ~CentralMoments.mom
      ~CentralMoments.mom_ndim
      ~CentralMoments.mom_shape
      ~CentralMoments.mom_shape_var
      ~CentralMoments.ndim
      ~CentralMoments.shape
      ~CentralMoments.shape_flat
      ~CentralMoments.shape_flat_var
      ~CentralMoments.shape_var
      ~CentralMoments.val_ndim
      ~CentralMoments.val_shape
      ~CentralMoments.val_shape_flat
      ~CentralMoments.values
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree: 
   
      ~CentralMoments.__add__
      ~CentralMoments.__iadd__
      ~CentralMoments.__imul__
      ~CentralMoments.__isub__
      ~CentralMoments.__mul__
      ~CentralMoments.__repr__
      ~CentralMoments.__sub__
   
   